slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPErrorType

The error type used to assess accuracy of computed solutions

### Synopsis

    typedef enum { PEP_ERROR_ABSOLUTE,
                   PEP_ERROR_RELATIVE,
                   PEP_ERROR_BACKWARD } PEPErrorType;

### See Also

PEPComputeError()

### Level

intermediate

### Location

include/slepcpep.h

### Examples

src/pep/tutorials/ex16.c.html
src/pep/tutorials/ex16f90.F90.html
src/pep/tutorials/ex17.c.html
src/pep/tutorials/ex28.c.html
src/pep/tutorials/ex38.c.html
src/pep/tutorials/ex40.c.html
src/pep/tutorials/ex50.c.html
src/pep/tutorials/nlevp/acoustic_wave_1d.c.html
src/pep/tutorials/nlevp/acoustic_wave_2d.c.html
src/pep/tutorials/nlevp/butterfly.c.html
src/pep/tutorials/nlevp/damped_beam.c.html
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages